%% UNDAMPED (GAYTON) OSCILLATOR
% This script contains the model and probabilistic input definitions for
% the 6-dimensional undamped oscillator.

%% 1 - INITIALIZE UQLAB
%
clearvars
uqlab

%% %% 2 - COMPUTATIONAL MODEL
%
ModelOpts.Name = 'undampedOscillatorModel';
ModelOpts.mFile = 'uq_undampedOscillator';
ModelOpts.isVectorized = true;

myModel = uq_createModel(ModelOpts);
clear ModelOpts

%% 3 - PROBABILISTIC INPUT MODEL
%
IOpts.Marginals(1).Name = 'C_1';         % First spring constant [-]
IOpts.Marginals(1).Type = 'Gaussian';
IOpts.Marginals(1).Moments = 1 * [1, 0.1];
    
IOpts.Marginals(2).Name = 'C_2';         % Second spring constant [-]
IOpts.Marginals(2).Type = 'Gaussian';
IOpts.Marginals(2).Moments = 0.1 * [1, 0.1];

IOpts.Marginals(3).Name = 'M';           % Oscillator Mass [-]
IOpts.Marginals(3).Type = 'Gaussian';
IOpts.Marginals(3).Moments = 1 * [1, 0.05];

IOpts.Marginals(4).Name = 'R';           % Yield displacement of springs [-]
IOpts.Marginals(4).Type = 'Gaussian';
IOpts.Marginals(4).Moments = 0.5 * [1, 0.1];

IOpts.Marginals(5).Name = 'F_1';         % Force acting on oscillator [-]
IOpts.Marginals(5).Type = 'Gaussian';
IOpts.Marginals(5).Moments = 0.6 * [1, 1/6];    

IOpts.Marginals(6).Name = 'T_1';         % Period the force is acting on oscillator
IOpts.Marginals(6).Type = 'Gaussian';
IOpts.Marginals(6).Moments = 1 * [1, 0.2];

myInput = uq_createInput(IOpts);
clear IOpts

